import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="autodiffing",
    version="0.0.1",
    author="Shuvom, Sijie, Silin, Edwin",
    author_email="ssadhuka@college.harvard.edu, sijiesun@g.harvard.edu, szou@g.harvard.edu, chng_weimingedwin@g.harvard.edu",
    description="A package for Automatic Differentiation",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/AutoDiffingFall2019/cs207-FinalProject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)
